Struct
QmiIndicationLocGnssSvInfoOutput
since: 1.22
Description [src]
struct QmiIndicationLocGnssSvInfoOutput {
/* No available fields */
}
The QmiIndicationLocGnssSvInfoOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.22
Instance methods
qmi_indication_loc_gnss_sv_info_output_get_altitude_assumed
Get the ‘Altitude Assumed’ field from self.
since: 1.22
qmi_indication_loc_gnss_sv_info_output_ref
Atomically increments the reference count of self by one.
since: 1.22
qmi_indication_loc_gnss_sv_info_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.22